class Headers:
    def oauth(self, token):
        '''
        Create a header included in each requests sending with this tools.
        Specify a Content-Type and Authorizations necessary for Dazzl API.

        @param token: String generated by backend service

        # Used in this way, but not tested because __dict__ are unpredictable on the order
        >>> Headers().oauth('SuperToken') # doctest: +SKIP
        ('Authorizations', 'Bearer SuperToken'), ('Content-Type', 'application/json')

        >>> sorted(Headers().oauth('SuperToken').items())
        [('Authorizations', 'Bearer SuperToken'), ('Content-Type', 'application/json')]
        '''
        return {
            'Content-Type': 'application/json',
            'Authorizations': 'Bearer '+token
        }


if __name__ == "__main__":
    import doctest
    doctest.testmod(report=False, raise_on_error=True)
